function [hoursprof s c A1 A2] = RWSim(hbar,mu,e0,e1,gamma,tau,gens)
%RWSim: Simulate the standard RW model and compute asset profile for given
%hbar mu e0 e1 gamma and tau. Use gens generations

step=1/gens;
time=0:step:1;
gens=gens+1;

h0min=hbar;h0max=1; %hmax is on [hbar,1]
while (h0max-h0min)> .000001
    h0n=.5*(h0min+h0max); %hmax midpoint
    % caluclate lamda_star at midpoint by inverting equation to calibrate hbar
    lamn=e0*(1-((1+gamma)*hbar/gamma./h0n).^gamma)/(e0-e1); 
    % calculate left hand side and right hand side of equation used to calibrate mu using lamn.
    % If rhs>lhs bring down h0max, if lhs<rhs bring up h0min
    int1=(e0*(1-lamn)+e1*lamn).^(1/gamma+2)-e0^(1/gamma+2); 
    int2=(e0*(1-lamn)+e1*lamn).^2-e0^2;
    rhsn=h0n/e0^(1/gamma)/(1/gamma+2)/(e1-e0).*int1-hbar/2/(e1-e0)*int2;
    lhsn=(1-tau)*e0./h0n.^gamma/mu;
    if rhsn > lhsn, h0max=h0n;else, h0min=h0n;end
end
lam=lamn;h0=h0n; %define true lamda and hnot

if(lam<=1) %interior solution
    %consumption
    c=h0/e0^(1/gamma)/(1/gamma+2)/(e1-e0)*((e0-(e0-e1)*lam)^(1/gamma+2)-e0^(1/gamma+2))...
        -hbar*e0*lam+hbar/2*(e0-e1)*lam^2; %consumption over life cycle

    %age-hours profile
    hoursprof=h0*((1-2.*abs(time-.5))+e1/e0.*(2.*abs(time-.5))).^(1/gamma); %hours-age profile
    hoursprof(find(time<=(.5-lam/2)))=0; hoursprof(find(time>.5+lam/2))=0;
    
    %compute asset profile analytically
    A1=.5-(lam/2);
    A2=.5+(lam/2);
    ind1=(time<A1);
    ind2=(time>=A1&time<=.5);
    ind3=(time>.5&time<=A2);
    ind4=(time>A2);

    s1=-time*c.*ind1;  
    s2=-time*c.*ind2+h0/2/(e0^(1/gamma))/(2+1/gamma)/(e0-e1).*...
        ((e1+2.*time.*(e0-e1)).^(2+1/gamma)-(e1+2*A1*(e0-e1))^(2+1/gamma)).*ind2...
        -hbar*e1*(time-A1).*ind2-hbar.*(time.^2-A1^2).*(e0-e1).*ind2;
    Ahalf =h0/2/(e0^(1/gamma))/(2+1/gamma)/(e0-e1).*...
        ((e1+2.*.5*(e0-e1))^(2+1/gamma)-(e1+2*A1*(e0-e1))^(2+1/gamma))...
        -hbar*e1*(.5-A1)-hbar.*((.5)^2-A1^2).*(e0-e1);
    s3=-time*c.*ind3+Ahalf.*ind3+h0/2/(2+1/gamma)/(e1-e0).*...
        ((2*e0-e1-2.*time.*(e0-e1)).^(2+1/gamma)-e0^(2+1/gamma)).*ind3...
        -hbar.*(2*e0-e1).*(time-.5).*ind3+hbar.*(time.^2-.5^2).*(e0-e1).*ind3;
    s4=-time*c.*ind4+c.*ind4;
    s=s1+s2+s3+s4;
else %corner solution
    lamn=1; %solve model with lamda=1
    A2=1; A1=1;
    h0min=hbar;h0max=1; %hmax is on [hbar,1]
    while (h0max-h0min)> .000001
        h0n=.5*(h0min+h0max); %hmax midpoint
        % calculate left hand side and right hand side of equation used to calibrate mu using lamn.
        % If rhs>lhs bring down h0max, if lhs<rhs bring up h0min
        int1=(e0*(1-lamn)+e1*lamn).^(1/gamma+2)-e0^(1/gamma+2); 
        int2=(e0*(1-lamn)+e1*lamn).^2-e0^2;
        rhsn=h0n/e0^(1/gamma)/(1/gamma+2)/(e1-e0).*int1-hbar/2/(e1-e0)*int2;
        lhsn=(1-tau)*e0./h0n.^gamma/mu;
        if rhsn > lhsn, h0max=h0n;else, h0min=h0n;end
    end
    lam=lamn;h0=h0n; %define true lamda and hnot
    
    %consumption
    c=h0/e0^(1/gamma)/(1/gamma+2)/(e1-e0)*((e0-(e0-e1)*lam)^(1/gamma+2)-e0^(1/gamma+2))...
        -hbar*e0*lam+hbar/2*(e0-e1)*lam^2; %consumption over life cycle

    %age-hours profile
    hoursprof=h0*((1-2.*abs(time-.5))+e1/e0.*(2.*abs(time-.5))).^(1/gamma); %hours-age profile
    
    %compute asset profile
    e=((e0-2*(e0-e1)*abs(time-.5))/e0);
    s=-time*c+step*(e.*(hoursprof-hbar))*triu(ones(gens));
end
end

